@@ -4,7 +4,7 @@ import socket
 from kola import safe_call, logger
 
 
-class GStream(object):
+class Stream(object):
     """
     为了和tornado的IOStream接口匹配
     """
